methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('flutter_diktup_social_media');
The method channel used to interact with the native platform.
@visibleForTesting
final methodChannel = const MethodChannel('flutter_diktup_social_media');